#!/bin/sh

# vim: sw=4 ts=4

for x in /dev/md/* ; do
  mdadm --stop $x
done

for disk in $(list-harddrives | grep -v fd0 | awk '{printf $1 " "}'); do
    dd if=/dev/zero of=/dev/$disk bs=512 count=32
    parted -s /dev/${disk} mklabel gpt;
done

for drive in $(lsblk -idn -I8 -oNAME); do
    # clear existing data
    dd if=/dev/zero of=/dev/${drive} bs=512 count=32
    parted -s /dev/${drive} mklabel gpt
    # get drives type
    if [ $(cat /sys/block/${drive}/queue/rotational) -eq 1 ]; then
        hard_drive+=(${drive}) # hard disk drive
    elif [ $(cat /sys/block/${drive}/queue/rotational) -eq 0 ]; then
        solid_drive+=(${drive}) # solid state drive
    fi
done

SWSIZE=$(grep MemTotal /proc/meminfo  | awk '{print int($2/1024)+1}')
if [ ${SWSIZE} -gt 1024 ]; then
    SWSIZE=1024
fi

if [ ${#hard_drive[@]} -eq 2 ]; then
    if [ -d /sys/firmware/efi ]; then
        efibootmgr -v | grep BootCurrent | cut -d' ' -f2 > /tmp/efi_booted
        echo "part raid.11 --size=250 --asprimary --ondisk=${hard_drive[0]}" > /tmp/part-include
        echo "part raid.21 --size=250 --asprimary --ondisk=${hard_drive[1]}" >> /tmp/part-include
        echo "raid /boot/efi --fstype efi --level=RAID1 --device=md0 raid.11 raid.21" >> /tmp/part-include
        echo "bootloader --location=mbr --boot-drive=${hard_drive[0]} --driveorder=${hard_drive[0]},${hard_drive[1]} --append="consoleblank=0 fsck.repair=yes"" >> /tmp/part-include
    else
        # bios boot partition necessary
        echo "bootloader --location=mbr --boot-drive=${hard_drive[0]} --driveorder=${hard_drive[0]},${hard_drive[1]} --append="consoleblank=0 fsck.repair=yes"" >> /tmp/part-include
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${hard_drive[0]}" > /tmp/part-include
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${hard_drive[1]}" >> /tmp/part-include
    fi
    cat >> /tmp/part-include << EOF
part raid.12 --size=${SWSIZE} --asprimary --ondisk=${hard_drive[0]}
part raid.13 --size=35840 --asprimary --ondisk=${hard_drive[0]}
part raid.14 --size=1 --grow --asprimary --ondisk=${hard_drive[0]}
part raid.22 --size=${SWSIZE} --asprimary --ondisk=${hard_drive[1]}
part raid.23 --size=35840 --asprimary --ondisk=${hard_drive[1]}
part raid.24 --size=1 --grow --asprimary --ondisk=${hard_drive[1]}
raid swap --fstype swap --level=RAID1 --device=md1 raid.12 raid.22
raid / --fstype xfs --level=RAID1 --device=md2 raid.13 raid.23
raid /vm --fstype xfs --level=RAID1 --fsoptions=noatime,logbsize=256k --device=md3 raid.14 raid.24
EOF
elif [ ${#solid_drive[@]} -eq 2 ]; then
    if [ -d /sys/firmware/efi ]; then
        efibootmgr -v | grep BootCurrent | cut -d' ' -f2 > /tmp/efi_booted
        echo "part raid.11 --size=250 --asprimary --ondisk=${hard_drive[0]}" > /tmp/part-include
        echo "part raid.21 --size=250 --asprimary --ondisk=${hard_drive[1]}" >> /tmp/part-include
        echo "raid /boot/efi --fstype efi --level=RAID1 --device=md0 raid.11 raid.21" >> /tmp/part-include
        echo "bootloader --location=mbr --boot-drive=${hard_drive[0]} --driveorder=${hard_drive[0]},${hard_drive[1]} --append="consoleblank=0 fsck.repair=yes"" >> /tmp/part-include
    else
        # bios boot partition necessary
        echo "bootloader --location=mbr --boot-drive=${hard_drive[0]} --driveorder=${hard_drive[0]},${hard_drive[1]} --append="consoleblank=0 fsck.repair=yes"" >> /tmp/part-include
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${hard_drive[0]}" > /tmp/part-include
        echo "part biosboot --fstype=biosboot --size=1 --ondisk=${hard_drive[1]}" >> /tmp/part-include
    fi
    cat >> /tmp/part-include << EOF
part raid.12 --size=${SWSIZE} --asprimary --ondisk=${hard_drive[0]}
part raid.13 --size=35840 --asprimary --ondisk=${hard_drive[0]}
part raid.14 --size=1 --grow --asprimary --ondisk=${hard_drive[0]}
part raid.22 --size=${SWSIZE} --asprimary --ondisk=${hard_drive[1]}
part raid.23 --size=35840 --asprimary --ondisk=${hard_drive[1]}
part raid.24 --size=1 --grow --asprimary --ondisk=${hard_drive[1]}
raid swap --fstype swap --level=RAID1 --device=md1 raid.12 raid.22
raid / --fstype xfs --level=RAID1 --device=md2 raid.13 raid.23
raid /vm --fstype xfs --level=RAID1 --fsoptions=noatime,logbsize=256k --device=md3 raid.14 raid.24
EOF
fi
